/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics.matcher;

import com.topcoder.file.statistics.FileMatcher;

import com.topcoder.util.config.Property;

import java.io.File;


/**
 * <p>
 * Implements the <code>FileMatcher</code> interface to provide the functionality to match any file. There is no
 * configuration for this class. However, in order to be used by <code>FileProcessor</code> implementations, an
 * empty constructor with <code>Property</code> argument is available.
 * </p>
 *
 * <p>
 * This class is thread-safe, since it is stateless.
 * </p>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 1.0
 */
public class AnyFileMatcher implements FileMatcher {
    /**
     * <p>
     * Creates a new instance of <code>AnyFileMatcher</code> class.
     * </p>
     */
    public AnyFileMatcher() {
    }

    /**
     * <p>
     * Creates a new instance of <code>AnyFileMatcher</code> class. This class does not require any configuration.
     * </p>
     *
     * @param property the property where configurations are read from.
     *
     * @throws NullPointerException if <code>property</code> is <code>null</code>.
     */
    public AnyFileMatcher(Property property) {
        Validator.validateNotNull(property, "property");
    }

    /**
     * <p>
     * Gets a flag indicating whether a file matches the criteria defined by this file matcher. It always returns
     * <code>true</code>.
     * </p>
     *
     * @param file the file to be matched.
     *
     * @return <code>true</code> indicating any file can be matched by this file matcher.
     *
     * @throws NullPointerException if <code>file</code> is <code>null</code>.
     */
    public boolean match(File file) {
        Validator.validateNotNull(file, "file");

        return true;
    }
}



