/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * Defines an interface with the functionality to propose and process custom command line switches.
 * <code>FileStatistics</code>, <code>FileProcessor</code>, <code>FileMatcher</code> and
 * <code>StatsReporting</code> implementations can support custom command line switches by implementing this interface.
 * Before the handler receiving the command line switches, certain validation can be done by specifying the required
 * flag and object validator in <code>ArgumentOption</code> instances.
 * </p>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 2.0b
 * @since 2.0b
 */
public interface ArgumentHandler {
    /**
     * <p>
     * Gets a list of custom argument options which can be processed by this handler.
     * </p>
     *
     * @return a list of <code>ArgumentOption</code> instances representing the switches can be processed by this
     *         handler.
     */
    public List proposeOptions();

    /**
     * <p>
     * Handles the argument received from the command line. The keys of the map are switch names specified in command
     * line. The values are switch values.
     * </p>
     *
     * @param arguments the argument names and values received from the command line.
     * @throws NullPointerException if <code>arguments</code> is <code>null</code>.
     * @throws IllegalArgumentExcpetion if the value of a switch is not a string.
     * @throws InvalidArgumentException if the value of a switch is invalid.
     */
    public void handleArguments(Map arguments) throws InvalidArgumentException;
}


