/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics;

import java.io.File;
import java.io.IOException;


/**
 * <p>
 * Defines an interface with the functionality to decide whether a given file matches a certain criteria.  The
 * criteria may include file name, file path and/or file content. In this component, <code>FileMatcher</code>
 * instances are used by <code>FileMatcher</code> implementations to decide whether a given file should be processed
 * or not.
 * </p>
 *
 * <p>
 * In order to be used by <code>FileProcessor</code>, an implementation must provide a constructor with a
 * <code>Property</code> instance as argument where configuration properties are read from.
 * </p>
 *
 * <p>
 * Implementations may also implement <code>ArgumentHandler</code> interface if additional command line configuration
 * is needed.
 * </p>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 2.0b
 * @since 1.0
 */
public interface FileMatcher {
    /**
     * <p>
     * Gets a flag indicating whether the given file matches the criteria defined by the specific implementation.
     * </p>
     *
     * @param file the file to be matched.
     *
     * @return <code>true</code> if the given file matches the criteria; <code>false</code> otherwise.
     *
     * @throws NullPointerException if <code>file</code> is <code>null</code>.
     * @throws IOException if I/O error occurs.
     * @throws FileMatchingException if any other error occurs when matching the file.
     */
    public boolean match(File file) throws IOException, FileMatchingException;
}




