/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.accuracytests.processor;

import junit.framework.TestCase;

import com.topcoder.file.statistics.FileProcessor;
import com.topcoder.file.statistics.accuracytests.TestHelper;
import com.topcoder.file.statistics.matcher.ExtensionMatcher;
import com.topcoder.file.statistics.matcher.TypeNameMatcher;
import com.topcoder.util.config.ConfigManager;
import com.topcoder.util.config.Property;


/**
 * <p>
 * Accuracy tests for FileProcessorBase
 * </p>
 *
 * @author cucu
 * @version 1.0
 */
public class FileProcessorBaseAccuracyTests extends TestCase {


    /**
     * Test that the alias and the file matcher are correctly loaded from configuration manager
     */
    public void testLoadingFromConfigManager() throws Exception  {
        try {
            TestHelper.loadConfig(TestHelper.PROCESSOR_CONFIG);
            Property prop1 = ConfigManager.getInstance().getPropertyObject(TestHelper.PROCESSOR_NAMESPACE, "processors.processor1");
            Property prop2 = ConfigManager.getInstance().getPropertyObject(TestHelper.PROCESSOR_NAMESPACE, "processors.processor2");

            FileProcessor fp = new MockProcessor(prop1);
            assertEquals("Bad alias retrieved for processor1", "Text File", fp.getAlias());
            assertTrue("Bad File matcher class for processor1", fp.getFileMatcher() instanceof ExtensionMatcher);

            fp = new MockProcessor(prop2);

            assertEquals("Bad alias retrieved for processor2", "Type File", fp.getAlias());
            assertTrue("Bad File matcher class for processor2", fp.getFileMatcher() instanceof TypeNameMatcher);

        } finally {
            TestHelper.unloadNamespace(TestHelper.PROCESSOR_CONFIG);

        }
    }

}
